==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicSplitPaneDivider__24VerticalDragController.h <==
// public class javax.swing.plaf.basic.BasicSplitPaneDivider$VerticalDragController

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ca0b0909401b5983 javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController
// @dep_class c27ae6f05426f69 javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController

#include "javax/swing/plaf/basic/BasicSplitPaneDivider__24DragController.h"

#ifndef _JC_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController_H_
#define _JC_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_refs	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$refs	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$nonrefs	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vmethods	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtable	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtype	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$method$_init$8153ddfe73b0b39e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider$object *, struct _jc_java_awt_event_MouseEvent$object *);

// Virtual methods
extern jint _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$method$adjust$7a53c1462d88e12a(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object *, jint, jint);
extern jint _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$method$getNeededLocation$53e4c1f7fd2b2455(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object *, jint, jint);
extern jint _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$method$positionForMouseEvent$fe345730aff0e259(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object *, struct _jc_java_awt_event_MouseEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$method_info$adjust$7a53c1462d88e12a;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$method_info$getNeededLocation$53e4c1f7fd2b2455;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$method_info$positionForMouseEvent$fe345730aff0e259;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vmethods {
	jint	(*adjust$7a53c1462d88e12a)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object *, jint, jint);
	jint	(*getNeededLocation$53e4c1f7fd2b2455)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object *, jint, jint);
	jint	(*positionForMouseEvent$fe345730aff0e259)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object *, struct _jc_java_awt_event_MouseEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController$vmethods	javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController;
	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vmethods	javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$refs {
    _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_refs	javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController;
    _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController$sub_refs	javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController$sub_nonrefs	javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController;
    _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_nonrefs	javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object {
	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtype _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicSplitPaneDivider__24VerticalDragController.h <==
// public class javax.swing.plaf.basic.BasicSplitPaneDivider$VerticalDragController

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class af6b4053d7f0b269 javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController
// @dep_class 4eca09faa83049f0 javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController

#include "javax/swing/plaf/basic/BasicSplitPaneDivider__24DragController.h"

#ifndef _JC_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController_H_
#define _JC_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_refs	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$refs	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$nonrefs	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vmethods	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtable	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtype	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$method$_init$8153ddfe73b0b39e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$method$adjust$7a53c1462d88e12a(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object *, jint, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$method$getNeededLocation$53e4c1f7fd2b2455(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object *, jint, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$method$positionForMouseEvent$fe345730aff0e259(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$method_info$adjust$7a53c1462d88e12a;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$method_info$getNeededLocation$53e4c1f7fd2b2455;
extern _jc_method _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$method_info$positionForMouseEvent$fe345730aff0e259;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vmethods {
	jint	(*adjust$7a53c1462d88e12a)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object *, jint, jint) _JC_JCNI_ATTR;
	jint	(*getNeededLocation$53e4c1f7fd2b2455)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object *, jint, jint) _JC_JCNI_ATTR;
	jint	(*positionForMouseEvent$fe345730aff0e259)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController$vmethods	javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController;
	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vmethods	javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$refs {
    _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_refs	javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController;
    _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController$sub_refs	javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController$sub_nonrefs	javax_swing_plaf_basic_BasicSplitPaneDivider__24DragController;
    _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$sub_nonrefs	javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$object {
	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$vtype _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicSplitPaneDivider__24VerticalDragController_H_ */
